% _fitsread.m: Simple function to read a FITS file.
%
% Needed for Octave (with Matlab, you can use fitsread).
%
% Arguments:
%   name   - Name of FITS file.
%   offset - Number of 2800-byte blocks to skip for the header.
%   bitpix - Bit per pixels of data to read.
%   shape  - Dimensions of the array to read.
%   scale  - Parameters [BSCALE,BZERO] to fix the file value.
%
function x = _fitsread(name, offset, bitpix, shape, scale)
    if bitpix == 8
        type = 'uint8';
    elseif bitpix == 16
        type = 'int16';
    elseif bitpix == 32
        type = 'int32';
    elseif bitpix == 64
        type = 'int64';
    elseif bitpix == -32
        type = 'float';
    elseif bitpix == -64
        type = 'double';
    else
        error('bad bitpix value');
    end
    f = fopen(name,'rb','ieee-be');
    fseek(f,2880*offset,'bof');
    x = scale(1)*double(fread(f,shape,type)) + scale(2);
    fclose(f);
end

